#' @useDynLib PPRL
#' @import Rcpp
#' @importFrom Rcpp evalCpp
#' @exportPattern "^[[:alpha:]]+"
"_PACKAGE"
